@@ -56,7 +56,7 @@
     <message>
         <location filename="../about_dlg.py" line="50"/>
         <source>&lt;p&gt;Heimen Stoffels &lt;a href=&quot;mailto:vistausss@outlook.com&quot;&gt;vistausss@outlook.com&lt;/a&gt;&lt;br/&gt; [nl] Dutch translation</source>
-        <translation>&lt;p&gt;Heimen Stoffels &lt;a href=&quot;mailto:vistausss@outlook.com&quot;&gt;vistausss@outlook.com&lt;/a&gt;&lt;br/&gt;[nl] Nederlandse vertaling</translation>
+        <translation>&lt;p&gt;Heimen Stoffels &lt;a href=&quot;mailto:vistausss@fastmail.com&quot;&gt;vistausss@fastmail.com&lt;/a&gt;&lt;br/&gt;[nl] Nederlandse vertaling</translation>
     </message>
     <message>
         <location filename="../about_dlg.py" line="50"/>
@@ -2188,8 +2188,8 @@ een breed gevoerde hoed. Breng niet te veel tijd door in de zon.</translation>
         <location filename="../searchcity.py" line="354"/>
         <source>Data error, please try again later
 or modify the name of the city</source>
-        <translation>Gegevensfout: probeer het later opnieuw
-of wijzig de locatienaam.</translation>
+        <translation>Gegevensfout, probeer het later opnieuw
+of wijzig de naam van de stad</translation>
     </message>
     <message>
         <location filename="../searchcity.py" line="390"/>
@@ -2199,7 +2199,7 @@ of wijzig de locatienaam.</translation>
     <message>
         <location filename="../searchcity.py" line="398"/>
         <source>Error: </source>
-        <translation>Fout:</translation>
+        <translation>Fout: </translation>
     </message>
     <message>
         <location filename="../searchcity.py" line="398"/>
