@@ -301,7 +301,7 @@ Ląd: gałęzie o umiarkowanej wielkości poruszają się. Małe drzewa w liści
         <source>Sea: Long waves begin to form. White foam crests are very frequent. Some airborne spray is present
 Land: Large branches in motion. Whistling heard in overhead wires. Umbrella use becomes difficult. Empty plastic bins tip over</source>
         <comment>Tooltip in Weather overview dialogue</comment>
-        <translation>Morze: zaczynają tworzyć się długie fale. Bardzo częste są białe grzebienie piankowe. Występuje niewielka ilość rozyplonej wody unoszącej się w powietrzu.
+        <translation>Morze: zaczynają tworzyć się długie fale. Bardzo częste są białe grzebienie piankowe. Występuje niewielka ilość rozpylonej wody unoszącej się w powietrzu.
 Ląd: duże gałęzie w ruchu. W przewodach napięcia elektrycznego słychać syczenie. Używanie parasola jest trudne. Puste plastikowe pojemniki przewracają się.</translation>
     </message>
 </context>
@@ -323,7 +323,7 @@ Ląd: całe drzewa w ruchu. Trzeba podjąć wysiłek, aby płynąć pod wiatr.</
         <source>Sea: Moderately high waves with breaking crests forming spindrift. Well-marked streaks of foam are blown along wind direction. Considerable airborne spray
 Land: Some twigs broken from trees. Cars veer on road. Progress on foot is seriously impeded</source>
         <comment>Tooltip in Weather overview dialogue</comment>
-        <translation>Morze: srednio wysokie fale z załamującymi się grzbietami tworzącymi wrzeciono. Dobrze widoczne smugi piany unoszone są w kierunku wiatru. Silne rozpylenie wody w powietrzu.
+        <translation>Morze: średnio wysokie fale z załamującymi się grzbietami tworzącymi wrzeciono. Dobrze widoczne smugi piany unoszone są w kierunku wiatru. Silne rozpylenie wody w powietrzu.
 Ląd: niektóre gałązki odrywają się od drzew. Wiatr na drodze ma wpływ na samochody. Chodzenie jest bardzo trudne.</translation>
     </message>
 </context>
@@ -386,7 +386,7 @@ Ląd: niektóre gałęzie odrywają się od drzew, a niektóre małe drzewa prze
     <message>
         <location filename="../citylistdlg.py" line="44"/>
         <source>&amp;Up</source>
-        <translation>Do &amp;góry</translation>
+        <translation>W &amp;górę</translation>
     </message>
     <message>
         <location filename="../citylistdlg.py" line="44"/>
@@ -587,7 +587,7 @@ Poniżej 990 hPa to wskazanie na SILNE i NIEBEZPIECZNE huragany, tornada i tajfu
         <comment>High https://en.wikipedia.org/wiki/Ultraviolet_index</comment>
         <translation>Używaj kremów z filtrem SPF 30+, noś ubrania z długimi rękawami. &lt;br/&gt;
 Chroń głowę nosząc kapelusze lub zakrywając głowę parasolem. &lt;br/&gt;
-Unikaj słońca co najmniej trzy godziny po południu. Noś okulary przeciw słoneczne.</translation>
+Unikaj słońca co najmniej trzy godziny po południu. Noś okulary przeciwsłoneczne.</translation>
     </message>
 </context>
 <context>
@@ -697,7 +697,7 @@ Unikaj słońca co najmniej trzy godziny po południu. Noś okulary przeciw sło
                 snow on&lt;br/&gt;the ground, which reflects UV radiation,
                 or if you have particularly fair skin.</source>
         <comment>Low https://en.wikipedia.org/wiki/Ultraviolet_index</comment>
-        <translation>Noś okulary przeciw słoneczne w intensywnie słoneczne dni. &lt;br/&gt;
+        <translation>Noś okulary przeciwsłoneczne w intensywnie słoneczne dni. &lt;br/&gt;
 Chroń skórę przez promieniowaniem UV, jeśli masz wrażliwą skórę.</translation>
     </message>
 </context>
@@ -810,7 +810,7 @@ Chroń skórę przez promieniowaniem UV, jeśli masz wrażliwą skórę.</transl
     <message>
         <location filename="../settings.py" line="82"/>
         <source>Norwegian (Bokmaal)</source>
-        <translation>Norweski (Bokmaal)</translation>
+        <translation>Norweski (bokmål)</translation>
     </message>
     <message>
         <location filename="../settings.py" line="83"/>
@@ -959,7 +959,7 @@ Chroń skórę przez promieniowaniem UV, jeśli masz wrażliwą skórę.</transl
         <location filename="../settings.py" line="146"/>
         <source>Km/h</source>
         <comment>Settings dialogue</comment>
-        <translation>Km/h</translation>
+        <translation>km/h</translation>
     </message>
 </context>
 <context>
@@ -1025,7 +1025,7 @@ Chroń skórę przez promieniowaniem UV, jeśli masz wrażliwą skórę.</transl
         <location filename="../searchcity.py" line="180"/>
         <source>N/A</source>
         <comment>Inserted in search field when the automaticgeolocalisation is not available</comment>
-        <translation>N/A</translation>
+        <translation>Brak</translation>
     </message>
 </context>
 <context>
@@ -1043,7 +1043,7 @@ Chroń skórę przez promieniowaniem UV, jeśli masz wrażliwą skórę.</transl
         <location filename="../searchcity.py" line="65"/>
         <source>Start typing the city or the ID or the geographic coordinates &quot;latitude, longitude&quot;</source>
         <comment>Default message in the search field</comment>
-        <translation>Wpisz nazwę miasta, lub ID, lub współrzędne geograficzne „szerokość, długość”</translation>
+        <translation>Wpisz nazwę miasta, lub ID, lub współrzędne geograficzne „szerokość, długość”.</translation>
     </message>
 </context>
 <context>
@@ -1118,7 +1118,7 @@ Chroń skórę przez promieniowaniem UV, jeśli masz wrażliwą skórę.</transl
         <location filename="../settings.py" line="264"/>
         <source>Icon &amp; Feels like temperature</source>
         <comment>Setting to choose the type of the icon on the tray</comment>
-        <translation>Ikona &amp; Odczuwalna temperatura</translation>
+        <translation>Ikona i odczuwalna temperatura</translation>
     </message>
     <message>
         <location filename="../settings.py" line="269"/>
@@ -1136,7 +1136,7 @@ Chroń skórę przez promieniowaniem UV, jeśli masz wrażliwą skórę.</transl
         <location filename="../settings.py" line="394"/>
         <source>seconds. Set to 0 to deactivate</source>
         <comment>Label after the spinbox to choose the interval to toggle the tray icon and temperature</comment>
-        <translation>sekundy. Ustaw 0 by wyłączyć.</translation>
+        <translation>sekundy. Ustaw 0, aby wyłączyć.</translation>
     </message>
     <message>
         <location filename="../settings.py" line="293"/>
@@ -1166,7 +1166,7 @@ Chroń skórę przez promieniowaniem UV, jeśli masz wrażliwą skórę.</transl
         <location filename="../settings.py" line="343"/>
         <source>Changing this setting you can improve the displaying of the temperature in the tray icon</source>
         <comment>ToolTip of the label &quot;Tray icon size and text position&quot;</comment>
-        <translation>Zmieniając to ustawienie, można poprawić wyświetlanie temperatury na ikonie zasobnika</translation>
+        <translation>Zmieniając to ustawienie, można poprawić wyświetlanie temperatury na ikonie zasobnika.</translation>
     </message>
     <message>
         <location filename="../settings.py" line="352"/>
@@ -1184,7 +1184,7 @@ Chroń skórę przez promieniowaniem UV, jeśli masz wrażliwą skórę.</transl
         <location filename="../settings.py" line="465"/>
         <source>It is suggested to use a personal key.&lt;br/&gt;If someone hijacks the default meteo-qt key you will not be able to get the weather data (error 401 unauthorized)</source>
         <comment>Tooltip of the api key text field</comment>
-        <translation>Sugeruje się użycie klucza osobistego.&lt;br/&gt;Jeśli ktoś przejmie domyślny klucz meteo-qt, nie będzie można uzyskać danych o pogodzie (błąd 401 nieautoryzowany)</translation>
+        <translation>Sugeruje się użycie klucza osobistego.&lt;br/&gt;Jeśli ktoś przejmie domyślny klucz meteo-qt, nie będzie można uzyskać danych o pogodzie (błąd 401 nieautoryzowany).</translation>
     </message>
 </context>
 <context>
@@ -1208,13 +1208,13 @@ Chroń skórę przez promieniowaniem UV, jeśli masz wrażliwą skórę.</transl
         <location filename="../searchcity.py" line="116"/>
         <source>Click on &quot;Find my Location&quot; button for automatic geolocation</source>
         <comment>City search dialogue</comment>
-        <translation>Kliknij przycisk &quot;Znajdź moją Lokalizację&quot; by zlokalizować automatycznie</translation>
+        <translation>Kliknij przycisk „Znajdź moją lokalizację”, aby zlokalizować automatycznie.</translation>
     </message>
     <message>
         <location filename="../searchcity.py" line="126"/>
         <source>Put the city&apos;s name, comma, 2-letter country code (ex: London, GB)</source>
         <comment>City search dialogue</comment>
-        <translation>Wpisz nazwę miasta, przecinek, 2-literowy kod kraju (np: Warszawa, PL)</translation>
+        <translation>Wpisz nazwę miasta, przecinek, 2-literowy kod kraju (np: Warszawa, PL).</translation>
     </message>
 </context>
 <context>
@@ -1275,12 +1275,12 @@ Chroń skórę przez promieniowaniem UV, jeśli masz wrażliwą skórę.</transl
     <message>
         <location filename="../meteo_qt.py" line="2004"/>
         <source>Right click on the icon and click on Settings.</source>
-        <translation>Prowoklik na ikonie, następnie kliknij Ustawienia.</translation>
+        <translation>Prawoklik na ikonie, następnie kliknij Ustawienia.</translation>
     </message>
     <message>
         <location filename="../meteo_qt.py" line="2584"/>
         <source>Fetching weather data...</source>
-        <translation>Pobieranie informacji o pogodzie ...</translation>
+        <translation>Pobieranie informacji o pogodzie...</translation>
     </message>
     <message>
         <location filename="../meteo_qt.py" line="2600"/>
@@ -1334,7 +1334,7 @@ Chroń skórę przez promieniowaniem UV, jeśli masz wrażliwą skórę.</transl
     <message>
         <location filename="../meteo_qt.py" line="1445"/>
         <source>Min Max Temperature of the day</source>
-        <translation>Min Max Temperatura w ciągu dnia</translation>
+        <translation>Temperatura min/max w ciągu dnia</translation>
     </message>
     <message>
         <location filename="../meteo_qt.py" line="2589"/>
@@ -1443,7 +1443,7 @@ Chroń skórę przez promieniowaniem UV, jeśli masz wrażliwą skórę.</transl
         <location filename="../settings.py" line="58"/>
         <source>The application has to be restared to apply the language setting</source>
         <comment>Settings dialogue</comment>
-        <translation>Program musi być zrestartowany, aby zastosować ustawienia językowe</translation>
+        <translation>Program musi być zrestartowany, aby zastosować ustawienia językowe.</translation>
     </message>
 </context>
 <context>
@@ -2102,7 +2102,7 @@ Nie przebywaj zbyt długo na słońcu.</translation>
     <message>
         <location filename="../conditions.py" line="133"/>
         <source>S</source>
-        <translation>pd.</translation>
+        <translation>S</translation>
     </message>
     <message>
         <location filename="../conditions.py" line="134"/>
@@ -2182,7 +2182,8 @@ Nie przebywaj zbyt długo na słońcu.</translation>
         <location filename="../searchcity.py" line="354"/>
         <source>Data error, please try again later
 or modify the name of the city</source>
-        <translation>Błąd danych, spróbuj ponownie później lub zmień nazwę miasta</translation>
+        <translation>Błąd danych, spróbuj ponownie później
+lub zmień nazwę miasta.</translation>
     </message>
     <message>
         <location filename="../searchcity.py" line="390"/>
